@@ -25,6 +25,9 @@ class CJpegLib:
         jpeg_color_space: int,
         marker_lengths,
         marker_types,
+        huffman_valid,
+        huffman_bits,
+        huffman_values,
         flags: List[str],
     ):
         status = cls.get().read_jpeg_info(
@@ -36,6 +39,9 @@ class CJpegLib:
             jpeg_color_space,
             marker_lengths,
             marker_types,
+            huffman_valid,
+            huffman_bits,
+            huffman_values,
             flags
         )
         if status == 0:
@@ -94,6 +100,7 @@ class CJpegLib:
         marker_types,
         marker_lengths,
         markers,
+        flags: List[str],
     ):
         status = cls.get().write_jpeg_dct(
             cls.cstr(srcfile),
@@ -112,7 +119,8 @@ class CJpegLib:
             num_markers,
             marker_types,
             marker_lengths,
-            markers
+            markers,
+            cls.flags_to_mask(flags),
         )
         if status == 0:
             raise IOError(f"writing DCT to {dstfile} failed")
@@ -189,7 +197,7 @@ class CJpegLib:
             marker_types,
             marker_lengths,
             markers,
-            cls.flags_to_mask(flags)
+            cls.flags_to_mask(flags),
         )
         if status == 0:
             raise IOError(f"writing spatial to {dstfile} failed")
